
# Slot: exactly_one_of


holds if only one of the expressions hold

URI: [linkml:exactly_one_of](https://w3id.org/linkml/exactly_one_of)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [Expression](Expression.md)

## Parents

 *  is_a: [boolean_slot](boolean_slot.md)

## Children

 *  [class_expression➞exactly_one_of](class_expression_exactly_one_of.md)
 *  [slot_expression➞exactly_one_of](slot_expression_exactly_one_of.md)
 *  [type_expression➞exactly_one_of](type_expression_exactly_one_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | sh:xone |

